@@ -62,7 +62,7 @@ BEMM.1PLG=function(data, 					#A matrix of response [n.examinees * n.items]
   }else{
     message('PROCEDURE TERMINATED WITH ISSUES')
   }
-  message('IRTEMM version: 1.0.5') 
+  message('IRTEMM version: 1.0.7') 
   message('Item Parameter Calibration for the 1PL-G Model.','\n')
   message('Quadrature: ', n.Quadpts, ' nodes from ', Theta.lim[1], ' to ', Theta.lim[2], ' were used to approximate Gaussian distribution.') 
   message('Method for Items: Ability-based Bayesian Expectation-Maximization-Maximization (BEMM) Algorithm.')
@@ -345,8 +345,8 @@ BEMM.1PLG.est=function(Model=Model, data=data, data.simple=data.simple, CountNum
       if (is.finite(delta1[2])==F || delta1[2]<=0){delta1[2] = 0}
       Par.SE0$SEBeta[j]= sqrt(IBeta[j] * delta1[1])
       Par.SE0$SEGamma[j]= sqrt(IGamma[j] * delta1[2])
-      if (Par.SE0$SEBeta[j]>1){Par.SE0$SEBeta[j]= sqrt(IBeta[j])}
-      if (Par.SE0$SEGamma[j]>1){Par.SE0$SEGamma[j]= sqrt(IGamma[j])}
+      if (is.finite(Par.SE0$SEBeta[j])){if (Par.SE0$SEBeta[j]>1){Par.SE0$SEBeta[j]= sqrt(IBeta[j])}}
+      if (is.finite(Par.SE0$SEGamma[j])){if (Par.SE0$SEGamma[j]>1){Par.SE0$SEGamma[j]= sqrt(IGamma[j])}}
     }
   }else{
     message('Directly estimating SEs from inversed Hession matrix.', '\n')
